@@ -25,6 +25,7 @@ from stat import *
 import pycurl
 from string import split, join
 from rfc822 import formatdate
+import errno
 
 from debpartial_mirror import DisplayStatus
 
@@ -107,7 +108,7 @@ class Curl:
 				try:
 					os.makedirs(os.path.dirname(self._curl.filename))
 				except OSError, (errno, msg):
-					if errno != 17:
+					if errno != errno.EEXIST:
 						print "ERROR:", msg
 				# (uri, destine, callback, error_callback, no_cache)
 				self.Queue.put((
